==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ad = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.g = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.afi != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.z = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.h("ShowGridlines", 2, a.afi != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.p = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.afi == null) {
                if (this.ad != null) {
                    c.afi = this.ad;
                }
                else {
                    c.afi = c.dataChart.z6;
                }
            }
        }
        else {
            if (c.afi != null) {
                this.ad = c.afi;
                c.afi = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ae = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.h = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.agc != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.aa = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.i("ShowGridlines", 2, a.agc != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.q = function (a, b) {
        var c = a;
        if (this.d(b, "ShowGridlines")) {
            if (c.agc == null) {
                if (this.ae != null) {
                    c.agc = this.ae;
                }
                else {
                    c.agc = c.dataChart.aaq;
                }
            }
        }
        else {
            if (c.agc != null) {
                this.ae = c.agc;
                c.agc = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };
